@@ -3,6 +3,7 @@ import sys
 from typing import List
 
 import flask
+from bs4 import Tag
 
 import PaperCrawlerUtil.global_val as global_val
 from proxypool.storages.proxy_dict import ProxyDict
@@ -160,7 +161,47 @@ class process_bar(object):
         self.bar.close()
 
 
-def get_timestamp(split: str or list = "-", accuracy: int = 6) -> str:
+def verify_rule(rule: dict, origin: float or str or Tag) -> bool:
+    """
+    verify the element string. if element satisfy all rules provided by rule arg,
+    return true.
+    :param rule:a dictionary that represent rules. the key is the match string and the value
+    is the rule. The rule is only support "in" and "not in" and "equal" and "not equal",
+    and more than, less than and greater or equal and less than or equal.
+     example:{"href": "in"}
+    :param origin:the string will be verified
+    :return:a bool value represent whether element satisfy all rule
+    """
+    if rule is None or len(rule) == 0:
+        return True
+    if origin is None:
+        return False
+    for key, value in rule.items():
+        if str(value) == IN and str(key) not in str(origin):
+            return False
+        elif str(value) == NOT_IN and str(key) in str(origin):
+            return False
+        elif str(value) == EQUAL and str(key) != str(origin):
+            return False
+        elif str(value) == NOT_EQUAL and str(key) == str(origin):
+            return False
+        elif str(value) == LESS_THAN or str(value) == LESS_THAN or str(value) == LESS_THAN_AND_EQUAL or str(
+                value) == MORE_THAN or str(value) == GREATER_AND_EQUAL:
+            if type(origin) != float and type(origin) != int:
+                return False
+            else:
+                if str(value) == LESS_THAN and float(origin) >= float(key):
+                    return False
+                elif str(value) == LESS_THAN_AND_EQUAL and float(origin) > float(key):
+                    return False
+                elif str(value) == GREATER_AND_EQUAL and float(origin) < float(key):
+                    return False
+                elif str(value) == MORE_THAN and float(origin) <= float(key):
+                    return False
+    return True
+
+
+def get_timestamp(split: str or list = ["-", "-", " ", ":", ":"], accuracy: int = 6) -> str:
     """
     %Y  Year with century as a decimal number.
     %m  Month as a decimal number [01,12].
@@ -766,4 +807,4 @@ class ThreadStopException(Exception):
 
 if __name__ == "__main__":
     basic_config(logs_style=LOG_STYLE_PRINT)
-    log(get_timestamp("-", accuracy=100))
+    # log(get_timestamp())
